---
title: <span class="badge builder"></span> AnnotationTarget
---
# <span class="badge builder"></span> AnnotationTarget

## Constructor

```python
AnnotationTarget()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.AnnotationTarget
```

### <span class="badge object-method"></span> limit

Only required/valid for the grafana datasource...

but code+tests is already depending on it so hard to change

```python
def limit(limit: int) -> typing.Self
```

### <span class="badge object-method"></span> match_any

Only required/valid for the grafana datasource...

but code+tests is already depending on it so hard to change

```python
def match_any(match_any: bool) -> typing.Self
```

### <span class="badge object-method"></span> tags

Only required/valid for the grafana datasource...

but code+tests is already depending on it so hard to change

```python
def tags(tags: list[str]) -> typing.Self
```

### <span class="badge object-method"></span> type_val

Only required/valid for the grafana datasource...

but code+tests is already depending on it so hard to change

```python
def type_val(type_val: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [AnnotationTarget](./object-AnnotationTarget.md)
